@@ -88,30 +88,32 @@ class ChessDaskCluster:
                 errno.ENOENT, os.strerror(errno.ENOENT), config_file)
         with open(config_file) as file:
             self.config_values = yaml.full_load(file)
-        if self.config_values["cluster_name"] is None:
+        if not "cluster_name" in self.config_values:
             self.config_values["cluster_name"] = "chess-cluster"
-        if self.config_values["software_environment_name"] is None:
+        if not "software_environment_name" in self.config_values:
             self.config_values["software_environment_name"] = "chess-env"
-        if self.config_values["n_workers"] is None:
+        if not "n_workers" in self.config_values:
             self.config_values["n_workers"] = 8
-        if self.config_values["worker_cpu"] is None:
+        if not "worker_cpu" in self.config_values:
             self.config_values["worker_cpu"] = 4
-        if self.config_values["worker_memory"] is None:
+        if not "worker_memory" in self.config_values:
             self.config_values["worker_memory"] = 16
-        if self.config_values["scheduler_memory"] is None:
+        if not "scheduler_memory" in self.config_values:
             self.config_values["scheduler_memory"] = 16
-        if self.config_values["scheduler_cpu"] is None:
+        if not "scheduler_cpu" in self.config_values:
             self.config_values["scheduler_cpu"] = 4
-        if self.config_values["game_batch_size"] is None:
+        if not "game_batch_size" in self.config_values:
             self.config_values["game_batch_size"] = 50
-        if self.config_values["timeout_per_game"] is None:
+        if not "timeout_per_game" in self.config_values:
             self.config_values["timeout_per_game"] = 30
+        if not "debug" in self.config_values:
+            self.config_values["debug"] = False
 
         config.set({"distributed.worker.daemon": False})
 
         if self.config_values["use_local_cluster"]:
             cluster = LocalCluster(n_workers=self.config_values["n_workers"],
-                                    threads_per_worker=4)
+                                    threads_per_worker=1)
         else:
             coiled.create_software_environment(name=self.config_values["software_environment_name"],
                                                 pip="requirements.txt")
@@ -150,8 +152,9 @@ class ChessDaskCluster:
             results.extend(self.client.gather(game_futures))
         print("Completed computation, starting image creation")
 
-        with open('results.json', 'w', encoding='utf-8') as f:
-            json.dump(results, f, ensure_ascii=False, indent=4)
+        if self.config_values["debug"]:
+            with open('results.json', 'w', encoding='utf-8') as f:
+                json.dump(results, f, ensure_ascii=False, indent=4)
         
         cleaned_results = results
         results = []
