@@ -51,6 +51,6 @@ class ChessImageGenerator:
 
         anim = animation.FuncAnimation(fig, animate, interval=1000,
                                         save_count=len(gamedata_mapwhite))
-        anim.save("resources/output/" + filename + ".gif", dpi=80, writer='imagemagick')
-        fh = open("resources/output/" + filename + ".gif", 'rb')
+        anim.save(filename + ".gif", dpi=80, writer='imagemagick')
+        fh = open(filename + ".gif", 'rb')
         return {"bytes": base64.b64encode(fh.read()), "filename": "resources/output/" + filename + ".gif"}
